==> kubernetes-model-rbac-6.7.0-sources.jar: io/fabric8/kubernetes/api/model/rbac/RoleBuilder.java <==
package io.fabric8.kubernetes.api.model.rbac;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class RoleBuilder extends RoleFluentImpl<RoleBuilder> implements VisitableBuilder<Role,RoleBuilder>{
  public RoleBuilder() {
    this(false);
  }
  public RoleBuilder(Boolean validationEnabled) {
    this(new Role(), validationEnabled);
  }
  public RoleBuilder(RoleFluent<?> fluent) {
    this(fluent, false);
  }
  public RoleBuilder(RoleFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new Role(), validationEnabled);
  }
  public RoleBuilder(RoleFluent<?> fluent,Role instance) {
    this(fluent, instance, false);
  }
  public RoleBuilder(RoleFluent<?> fluent,Role instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
      fluent.withRules(instance.getRules());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public RoleBuilder(Role instance) {
    this(instance,false);
  }
  public RoleBuilder(Role instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withRules(instance.getRules());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  RoleFluent<?> fluent;
  Boolean validationEnabled;
  public Role build() {
    Role buildable = new Role(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getRules());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> kubernetes-model-rbac-6.8.1-sources.jar: io/fabric8/kubernetes/api/model/rbac/RoleBuilder.java <==
package io.fabric8.kubernetes.api.model.rbac;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class RoleBuilder extends RoleFluent<RoleBuilder> implements VisitableBuilder<Role,RoleBuilder>{
  public RoleBuilder() {
    this(false);
  }
  public RoleBuilder(Boolean validationEnabled) {
    this(new Role(), validationEnabled);
  }
  public RoleBuilder(RoleFluent<?> fluent) {
    this(fluent, false);
  }
  public RoleBuilder(RoleFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new Role(), validationEnabled);
  }
  public RoleBuilder(RoleFluent<?> fluent,Role instance) {
    this(fluent, instance, false);
  }
  public RoleBuilder(RoleFluent<?> fluent,Role instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new Role());

    if (instance != null) {
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
      fluent.withRules(instance.getRules());
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
      fluent.withRules(instance.getRules());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public RoleBuilder(Role instance) {
    this(instance,false);
  }
  public RoleBuilder(Role instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new Role());

    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withRules(instance.getRules());
      this.withApiVersion(instance.getApiVersion());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withRules(instance.getRules());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  RoleFluent<?> fluent;
  Boolean validationEnabled;
  public Role build() {
    Role buildable = new Role(fluent.getApiVersion(),fluent.getKind(),fluent.buildMetadata(),fluent.buildRules());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
